
import { useRef, useState, useEffect } from 'react';
import { connect } from '@umijs/max';
import type { ActionType, ProFormInstance } from '@ant-design/pro-components';
import {
    ProFormText,
    ProFormSegmented,
    ProFormSelect,
    ProForm,
    FormControlRender,
    ProFormDependency,
    ProFormTextArea
} from '@ant-design/pro-components';
import { ConfigProvider, Flex, Space, Modal, message, Image, Row, Col, Switch, Form, Typography } from 'antd';
import { addArticle, updateArticle, listSection, GetArticleDetail } from '@/apis/api';
import { Imageprefix } from '@/constants';
import UploadModel from '@/components/Common/upload';
import DragUpload from '@/components/Common/dragupload';
import RichComponent from '@/components/Common/rich';

import { PostFeedbackUpdate, PostFeedbackDel, GetFeedbackList, GetFeedbackDetail } from '@/apis/api';

const selectfieldNames = { label: 'name', value: 'id' };


const PagesMainInformationArticleCreate: React.FC = ({ dispatch, dictModel, openModel, id }: any) => {
    const formRef = useRef<ProFormInstance>();
    const [openPreview, setOpenPreview] = useState(false);
    const [detail, setDetail] = useState<InformationType.article | null>(null)

    useEffect(() => {
        setOpenPreview(openModel.openModal)
    }, [openModel.openModal])

    
    return (
        <>
            <ConfigProvider
                theme={{
                    token: {
                        colorPrimary: '#4FBE70',
                    }, components: {
                        Segmented: {
                            itemSelectedBg: '#19be6e',
                            itemSelectedColor: '#ffffff'
                        },
                    },
                }}
            >
                <Modal
                    open={openPreview}
                    title='处理反馈结果'
                    centered
                    maskClosable={false}
                    footer={null}
                    destroyOnClose
                    width={1000}
                    onCancel={() => {
                        dispatch({ type: 'openModel/getOpenModal', payload: false })
                    }}
                >
                    <ProForm
                        formRef={formRef}
                        request={async () => {
                            if (id.id) {
                                return id;
                            } else {
                                return {
                                    "name": "",
                                    "address": "",
                                    "telephone": "",
                                    "fax": "",
                                    "postal": "",
                                    "email": "",
                                    "content": "",
                                    feed_back: ''
                                }
                            }
                        }}
                        submitter={{
                            searchConfig: {
                                resetText: '取消',
                                submitText: '保存',
                            },
                            render: (_, dom) => { return <Flex justify='flex-end'> <Space>{dom}</Space></Flex> },
                            onReset: () => {
                                setDetail(null)
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            }
                        }}
                        onFinish={async (values) => {
                            if (id) {
                                values.id = id;
                                let res = await PostFeedbackUpdate(values)
                                message.success('提交成功')
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            }
                        }}
                    >

                        <ProFormText
                            name="name"
                            label="昵称"
                            placeholder="请输入姓名"
                            fieldProps={{disabled:true}}
                        />
                        <ProFormText
                            name="telephone"
                            label="电话"
                            placeholder="请输入电话"
                            fieldProps={{disabled:true}}

                        />
                        <ProFormText
                            name="email"
                            label="电子邮箱"
                            placeholder="请输入电子邮箱"
                            fieldProps={{disabled:true}}

                        />
                        <ProFormTextArea
                            name="content"
                            label="反馈内容"
                            placeholder="请输入反馈内容"
                            fieldProps={{disabled:true}}

                        />
                         <ProFormTextArea
                            name="feed_back"
                            label="处理结果"
                            placeholder="请输入处理结果"
                            rules={[{ required: true, message: '请输入处理结果' }
                            ]}
                        />
                    </ProForm>
                </Modal>
            </ConfigProvider>
        </>
    );
};



export default connect(({ dictModel, openModel }: any) => ({
    dictModel, openModel
}))(PagesMainInformationArticleCreate);